# Element

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**uuid** | **str** |  | [optional] 
**type** | **str** | IFC type for the element | 
**attributes** | [**PropertySet**](PropertySet.md) |  | [optional] 
**property_sets** | [**list[PropertySet]**](PropertySet.md) |  | [optional] 
**classifications** | [**list[Classification]**](Classification.md) |  | [optional] 
**material_list** | [**list[MaterialListComponent]**](MaterialListComponent.md) |  | [optional] [readonly] 
**layers** | [**list[LayerElement]**](LayerElement.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


